@@ -43,7 +43,8 @@ LINE_LABEL_LIST['He1r'] = ['5876A', '2945A', '3188A', '3614A', '3889A', '3965A',
                           '12790A', '12846A', '12968A', '12985A', '13412A', '15084A', '17003A', '18556A',
                           '18685A', '18697A', '19089A', '19543A', '20425A', '20581A', '20602A', '21120A',
                           '21132A', '21608A', '21617A']
-LINE_LABEL_LIST['He2r'] = ['1640A', '1215A', '1084A', '4686A', '3203A','6560A', '5411A','4859A']
+LINE_LABEL_LIST['He2r'] = ['1640A', '1215A', '1084A', '4686A', '3203A','6560A', '5411A','4859A', '4541A', '6407A', 
+                           '4198A']
 LINE_LABEL_LIST['3He2'] = ['3.50c']
 LINE_LABEL_LIST['Al2'] = ['2674A', '2670A', '2661A', '1671A', '4451A', '4463A', '4488A', '164.2m', '54.1m', '80.7m']
 LINE_LABEL_LIST['Ar2'] = ['7.0m']
